@@ -2,7 +2,7 @@
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
-# $Id: test.pl,v 1.35 2005/09/15 23:34:20 jrennie Exp $
+# $Id: test.pl,v 1.36 2005/12/30 18:06:46 jrennie Exp $
 
 my $i = 1;
 BEGIN { 
@@ -146,10 +146,12 @@ if ($ver eq "2.0")
 	? print "ok ", $i++, "\n" : print "not ok ", $i++, "\n";
     ($wn->querySense('acropetal#a#1', 'dmnc'))[0] eq 'botany#n#1'
 	? print "ok ", $i++, "\n" : print "not ok ", $i++, "\n";
+    print scalar $wn->offset("0#n#1"), "\n";
     scalar $wn->offset("0#n#1") == 12967124
 	? print "ok ", $i++, "\n" : print "not ok ", $i++, "\n";
     scalar $wn->listAllWords("noun") == 114648
 	? print "ok ", $i++, "\n" : print "not ok ", $i++, "\n";
+    print $wn->offset("child#n#1"), "\n";
     $wn->offset("child#n#1") == 9284669
 	? print "ok ", $i++, "\n" : print "not ok ", $i++, "\n";
     my ($foo) = $wn->querySense ("cat#n#1", "glos");
